@@ -1,9 +1,10 @@
 import asyncio
 import contextlib
 import logging
-from typing import Callable, Coroutine, Optional
+from typing import Callable, Coroutine, List, Optional
 
 from .aioprotocol import AIOLEDENETProtocol
+from .base_device import LEDENETDevice
 from .const import (
     STATE_BLUE,
     STATE_COOL_WHITE,
@@ -11,7 +12,6 @@ from .const import (
     STATE_RED,
     STATE_WARM_WHITE,
 )
-from .device import LEDENETDevice
 from .protocol import ProtocolLEDENET8Byte, ProtocolLEDENETOriginal
 from .utils import color_temp_to_white_levels
 
@@ -30,8 +30,8 @@ class AIOWifiLedBulb(LEDENETDevice):
         super().__init__(ipaddr, port, timeout)
         self._lock = asyncio.Lock()
         self._aio_protocol: Optional[AIOLEDENETProtocol] = None
-        self._on_futures: list[asyncio.Future] = []
-        self._off_futures: list[asyncio.Future] = []
+        self._on_futures: List[asyncio.Future] = []
+        self._off_futures: List[asyncio.Future] = []
         self._data_future: Optional[asyncio.Future] = None
         self._updated_callback: Optional[Callable] = None
         self._updates_without_response = 0
@@ -49,7 +49,7 @@ class AIOWifiLedBulb(LEDENETDevice):
             self._aio_protocol.close()
 
     async def _async_execute_and_wait_for(
-        self, futures: list[asyncio.Future], coro: Coroutine
+        self, futures: List[asyncio.Future], coro: Coroutine
     ) -> None:
         future = asyncio.Future()
         futures.append(future)
@@ -162,6 +162,12 @@ class AIOWifiLedBulb(LEDENETDevice):
         msg = self._generate_custom_patterm(rgb_list, speed, transition_type)
         await self._async_send_msg(msg)
 
+    async def async_set_effect(self, effect, speed):
+        """Set an effect."""
+        return await self.async_set_preset_pattern(
+            self._effect_to_pattern(effect), speed
+        )
+
     async def _async_connect(self):
         """Create connection."""
         _, self._aio_protocol = await asyncio.wait_for(
