@@ -18,6 +18,7 @@ COLOR_MODE_RGBWW = "RGBWW"
 COLOR_MODE_ADDRESSABLE = "ADDRESSABLE"
 
 STATE_CHANGE_LATENCY = 1
+ADDRESSABLE_STATE_CHANGE_LATENCY = 5
 MIN_TEMP = 2700
 MAX_TEMP = 6500
 
@@ -51,6 +52,8 @@ COLOR_MODES_RGB_W = {  # AKA RGB/W in the Magic Home Pro app
     COLOR_MODE_RGB,
     COLOR_MODE_DIM,
 }
+COLOR_MODES_ADDRESSABLE = {COLOR_MODE_RGB}
+
 
 DEFAULT_MODE = COLOR_MODE_RGB
 
